@@ -11,6 +11,7 @@ import (
 )
 
 type Format interface {
+	SetSchema(physical.Schema)
 	WriteRecord(Record) error
 	WriteMeta(MetadataMessage) error
 	Close() error
@@ -63,6 +64,10 @@ func (n *NativeFormat) WriteMeta(message MetadataMessage) error {
 	return nil
 }
 
+func (n *NativeFormat) SetSchema(schema physical.Schema) {
+	n.schema = schema
+}
+
 func (n *NativeFormat) Close() error {
 	return nil
 }
